gkirby

package module
v0.0.0-...-b88c6fe Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 12, 2024 License: MIT Imports: 6 Imported by: 0

README

Gscript Kerberos (gkirby)

Gscript library to facilitate raw Kerberos interactions, similar to GhostPack's Rubeus.

About

gkirby builds upon the groundwork laid out by Alex Levinson and Dan Borges by exposing a simple API to enable common Kerberos attacks such as dumping cached tickets (more to come).

API Docs

Ticket Extracting and Harvesting

GetKerberosTickets(): returns a []map[string]interface{} of Kerberos tickets, which is essentially just a HashMap that can be used from the JS frontend.

function Deploy() {
    var tickets = kerberos.GetKerberosTickets();
    if (tickets === null) {
        console.log("Failed to get tickets");
        return false;
    }
    
    for (var i=0; i < ticket.length; i++) {
        var ticket = tickets[i];
        for (var key in ticket) {
            console.log(key + ': ' + ticket[key]);
        }
    }
    
    return true;
}

Documentation

Rendered for windows/amd64

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GetKerberosTickets

func GetKerberosTickets() []map[string]interface{}

return a map of kerberos tickets + base64 encoded ticket material

Types

This section is empty.

Directories

Path Synopsis

Jump to